
#include <windows.h>
#include <stdio.h>
#include "Zoom.h"
#include <vfw.h>


#if defined (WIN32)
	#define IS_WIN32 TRUE
#else
	#define IS_WIN32 FALSE
#endif

#define IS_NT      IS_WIN32 && (BOOL)(GetVersion() < 0x80000000)
#define IS_WIN32S  IS_WIN32 && (BOOL)(!(IS_NT) && (LOBYTE(LOWORD(GetVersion()))<4))
#define IS_WIN95   (BOOL)(!(IS_NT) && !(IS_WIN32S)) && IS_WIN32


HINSTANCE hInst;   // current instance

LPCTSTR lpszAppName = "MyApp";
LPCTSTR lpszTitle   = "My Application"; 

// the rest of the stuff
//......................

BOOL RegisterWin95( CONST WNDCLASS* lpwc );


int APIENTRY WinMain( HINSTANCE hInstance, HINSTANCE hPrevInstance,
                      LPTSTR lpCmdLine, int nCmdShow)
{
   MSG      msg;
   HWND     hWnd; 
   WNDCLASS wc;

   wc.style         = CS_HREDRAW | CS_VREDRAW | CS_OWNDC;
   wc.lpfnWndProc   = (WNDPROC)WndProc;       
   wc.cbClsExtra    = 0;                      
   wc.cbWndExtra    = 0;                      
   wc.hInstance     = hInstance;              
   wc.hIcon         = LoadIcon (hInstance, lpszAppName); 
   wc.hCursor       = LoadCursor(NULL, IDC_ARROW);
   wc.hbrBackground = (HBRUSH)(COLOR_WINDOW+1);
   wc.lpszMenuName  = lpszAppName;              
   wc.lpszClassName = lpszAppName;              

   if ( IS_WIN95 )
   {
      if ( !RegisterWin95( &wc ) )
         return( FALSE );
   }
   else if ( !RegisterClass( &wc ) )
      return( FALSE );

   hInst = hInstance; 

   hWnd = CreateWindow( lpszAppName, 
                        lpszTitle,    
                        WS_OVERLAPPEDWINDOW, 
                        CW_USEDEFAULT, 0, 
                        CW_USEDEFAULT, 0,  
                        NULL,              
                        NULL,              
                        hInstance,         
                        NULL               
                      );

   if ( !hWnd ) 
      return( FALSE );

   ShowWindow( hWnd, nCmdShow ); 
   UpdateWindow( hWnd );         

   while( GetMessage( &msg, NULL, 0, 0) )   
   {
      TranslateMessage( &msg ); 
      DispatchMessage( &msg );  
   }

   return( msg.wParam ); 
}


BOOL RegisterWin95( CONST WNDCLASS* lpwc )
{
	WNDCLASSEX wcex;

   wcex.style         = lpwc->style;
   wcex.lpfnWndProc   = lpwc->lpfnWndProc;
   wcex.cbClsExtra    = lpwc->cbClsExtra;
   wcex.cbWndExtra    = lpwc->cbWndExtra;
   wcex.hInstance     = lpwc->hInstance;
   wcex.hIcon         = lpwc->hIcon;
   wcex.hCursor       = lpwc->hCursor;
   wcex.hbrBackground = lpwc->hbrBackground;
   wcex.lpszMenuName  = lpwc->lpszMenuName;
   wcex.lpszClassName = lpwc->lpszClassName;

   // Added elements for Windows 95.
   //...............................
   wcex.cbSize = sizeof(WNDCLASSEX);
   wcex.hIconSm = LoadImage(wcex.hInstance, lpwc->lpszClassName, 
                            IMAGE_ICON, 16, 16,
                            LR_DEFAULTCOLOR );
			
   return RegisterClassEx( &wcex );
}

HWND hMCIWnd = NULL;   // MCIWnd window handle

LRESULT CALLBACK WndProc( HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam )
{
   switch( uMsg )
   {
      case WM_CREATE :
              // create MCIWnd window
              //.....................

              hMCIWnd = MCIWndCreate(hWnd, hInst, 
                                     WS_VISIBLE | 
                                     WS_CHILD | 
                                     WS_OVERLAPPED |
                                     WS_CAPTION |
                                     WS_BORDER |
                                     MCIWNDF_NOTIFYMODE |
                                     MCIWNDF_SHOWALL | 
                                     MCIWNDF_NOPLAYBAR, 
                                     NULL
                                    );
                          
              if (!hMCIWnd)
              {
                  MessageBox(hWnd, "Error creating MCIWnd window...", 
                             NULL, MB_OK);
                  DestroyWindow( hWnd );
              }
              break;

      case WM_COMMAND :
              switch( LOWORD( wParam ) )
              {
                 // file commands
                 //..............

                 case IDM_OPEN_DIALOG :
                         if ( MCIWndOpenDialog(hMCIWnd) )
                             MCIWndValidateMedia(hMCIWnd);
                         break;
                         
                 case IDM_CLOSE :
                         MCIWndClose(hMCIWnd);
                         break;

                 // playback
                 //.........
                                           
                 case IDM_PLAY :
                         MCIWndPlay(hMCIWnd);
                         break;
                                   
                 case IDM_STOP :
                         MCIWndStop(hMCIWnd);
                         break;
                 
                 // zoom size controls
                 //...................
                                           
                 case IDM_ZOOM_NORMAL :
                         MCIWndSetZoom(hMCIWnd, 100);
                         break;
                 
                 case IDM_ZOOM_INCREASE :    // increase 25% (250)
                         if (MCIWndGetZoom(hMCIWnd) < 400)
                             MCIWndSetZoom(hMCIWnd, MCIWndGetZoom(hMCIWnd) + 25);
                         break;
                 
                 case IDM_ZOOM_DECREASE :    // decrease 25% (250)
                         if (MCIWndGetZoom(hMCIWnd) > 25)
                             MCIWndSetZoom(hMCIWnd, MCIWndGetZoom(hMCIWnd) - 25);
                         break;

                 // other commands
                 //...............
                 
                 case IDM_ABOUT :
                        DialogBox( hInst, "AboutBox", hWnd, (DLGPROC)About );
                        break;

                 case IDM_EXIT :
                        DestroyWindow(hWnd);
                        break;
              }
              break;

      case WM_DESTROY :
              // destroy MCIWnd, if one exists
              //..............................

              if (hMCIWnd)
                  MCIWndDestroy(hMCIWnd);

              PostQuitMessage(0);
              break;

      default :
            return( DefWindowProc( hWnd, uMsg, wParam, lParam ) );
   }

   return( 0L );               
}


LRESULT CALLBACK About( HWND hDlg,           
                        UINT message,        
                        WPARAM wParam,       
                        LPARAM lParam)
{
   switch (message) 
   {
       case WM_INITDIALOG: 
               return (TRUE);

       case WM_COMMAND:                              
               if (   LOWORD(wParam) == IDOK         
                   || LOWORD(wParam) == IDCANCEL)    
               {
                       EndDialog(hDlg, TRUE);        
                       return (TRUE);
               }
               break;
   }

   return (FALSE); 
}









